Learn R Programming

carbonpredict (version 2.0.1)

sme_emissions_profile: SME Emissions Profile

Description

Calls the Scope 1, 2 and 3 emissions prediction functions and returns their results as a list and plots a donut chart

Usage

sme_emissions_profile(sic_code, turnover, company_name = NULL)

Value

A list with four elements: scope1, scope2

scope3, scope3_hotspots, each containing the predicted carbon emissions data frame (in tCo2e), the top 5 scope 3 emissions hotspots, as well as a donut chart and Sankey diagram showing the emissions breakdowns.

Arguments

sic_code

A 2-digit UK SIC code (numeric).

turnover

Annual turnover value (numeric).

company_name

Optional company name for labeling plots (character string).

Examples

Run this code
sme_emissions_profile(sic_code = 85, turnover = 12000000, company_name = "Carbon Predict LTD")

Run the code above in your browser using DataLab