scope3, scope3_hotspots, each containing the predicted carbon emissions data frame (in tCo2e), the top 5 scope 3 emissions hotspots, as well as a donut chart and Sankey diagram showing the emissions breakdowns.
Arguments
sic_code
A 2-digit UK SIC code (numeric).
turnover
Annual turnover value (numeric).
company_name
Optional company name for labeling plots (character string).